Algorithms
============

Algorithms have as input data (typically as a QCoDeS dataset) and parameters of the algorithm. 
The output is a dictionary with the main results as keys of the dictionary.


Quantum dots
------------

* Fit anti-crossing
* Virtual gate matrix
* Fit polarization line
* ...

Qubits
------

* PSB
* T1
* ...

Example notebooks
-----------------

Most of the algorithms are documented in the `Example notebooks`_ section.

Back to the :doc:`main page <index>`.
